@@ -7,17 +7,18 @@
 package testgraph // import "gonum.org/v1/gonum/graph/testgraph"
 
 import (
+	"cmp"
 	"fmt"
 	"reflect"
-	"sort"
+	"slices"
 	"testing"
 
 	"golang.org/x/exp/rand"
 
 	"gonum.org/v1/gonum/floats/scalar"
 	"gonum.org/v1/gonum/graph"
-	"gonum.org/v1/gonum/graph/internal/ordered"
 	"gonum.org/v1/gonum/graph/internal/set"
+	"gonum.org/v1/gonum/internal/order"
 	"gonum.org/v1/gonum/mat"
 )
 
@@ -126,8 +127,8 @@ func ReturnAllNodes(t *testing.T, b Builder, useEmpty bool) {
 			got = append(got, it.Node())
 		}
 
-		ordered.ByID(got)
-		ordered.ByID(want)
+		order.ByID(got)
+		order.ByID(want)
 
 		if !reflect.DeepEqual(got, want) {
 			t.Errorf("unexpected nodes result for test %q:\ngot: %v\nwant:%v", test.name, got, want)
@@ -165,8 +166,8 @@ func ReturnNodeSlice(t *testing.T, b Builder, useEmpty bool) {
 		}
 		got := s.NodeSlice()
 
-		ordered.ByID(got)
-		ordered.ByID(want)
+		order.ByID(got)
+		order.ByID(want)
 
 		if !reflect.DeepEqual(got, want) {
 			t.Errorf("unexpected nodes result for test %q:\ngot: %v\nwant:%v", test.name, got, want)
@@ -616,14 +617,14 @@ func checkEdges(t *testing.T, name string, g graph.Graph, got, want []Edge) {
 	t.Helper()
 	switch g.(type) {
 	case graph.Undirected:
-		sort.Sort(lexicalUndirectedEdges(got))
-		sort.Sort(lexicalUndirectedEdges(want))
+		sortLexicalUndirectedEdges(got)
+		sortLexicalUndirectedEdges(want)
 		if !undirectedEdgeSetEqual(got, want) {
 			t.Errorf("unexpected edges result for test %q:\ngot: %#v\nwant:%#v", name, got, want)
 		}
 	default:
-		sort.Sort(lexicalEdges(got))
-		sort.Sort(lexicalEdges(want))
+		sortLexicalEdges(got)
+		sortLexicalEdges(want)
 		if !reflect.DeepEqual(got, want) {
 			t.Errorf("unexpected edges result for test %q:\ngot: %#v\nwant:%#v", name, got, want)
 		}
@@ -1230,77 +1231,67 @@ func AdjacencyMatrix(t *testing.T, b Builder) {
 	}
 }
 
-// lexicalEdges sorts a collection of edges lexically on the
+// sortLexicalEdges sorts a collection of edges lexically on the
 // keys: from.ID > to.ID > [line.ID] > [weight].
-type lexicalEdges []Edge
-
-func (e lexicalEdges) Len() int { return len(e) }
-func (e lexicalEdges) Less(i, j int) bool {
-	if e[i].From().ID() < e[j].From().ID() {
-		return true
-	}
-	sf := e[i].From().ID() == e[j].From().ID()
-	if sf && e[i].To().ID() < e[j].To().ID() {
-		return true
-	}
-	st := e[i].To().ID() == e[j].To().ID()
-	li, oki := e[i].(graph.Line)
-	lj, okj := e[j].(graph.Line)
-	if oki != okj {
-		panic(fmt.Sprintf("testgraph: mismatched types %T != %T", e[i], e[j]))
-	}
-	if !oki {
-		return sf && st && lessWeight(e[i], e[j])
-	}
-	if sf && st && li.ID() < lj.ID() {
-		return true
-	}
-	return sf && st && li.ID() == lj.ID() && lessWeight(e[i], e[j])
+func sortLexicalEdges(edges []Edge) {
+	slices.SortFunc(edges, func(a, b Edge) int {
+		if n := cmp.Compare(a.From().ID(), b.From().ID()); n != 0 {
+			return n
+		}
+		if n := cmp.Compare(a.To().ID(), b.To().ID()); n != 0 {
+			return n
+		}
+		la, oka := a.(graph.Line)
+		lb, okb := b.(graph.Line)
+		if oka != okb {
+			panic(fmt.Sprintf("testgraph: mismatched types %T != %T", a, b))
+		}
+		if oka {
+			if n := cmp.Compare(la.ID(), lb.ID()); n != 0 {
+				return n
+			}
+		}
+		return cmpWeight(a, b)
+	})
 }
-func (e lexicalEdges) Swap(i, j int) { e[i], e[j] = e[j], e[i] }
 
-// lexicalUndirectedEdges sorts a collection of edges lexically on the
+// sortLexicalUndirectedEdges sorts a collection of edges lexically on the
 // keys: lo.ID > hi.ID > [line.ID] > [weight].
-type lexicalUndirectedEdges []Edge
+func sortLexicalUndirectedEdges(edges []Edge) {
+	slices.SortFunc(edges, func(a, b Edge) int {
+		lida, hida, _ := undirectedIDs(a)
+		lidb, hidb, _ := undirectedIDs(b)
 
-func (e lexicalUndirectedEdges) Len() int { return len(e) }
-func (e lexicalUndirectedEdges) Less(i, j int) bool {
-	lidi, hidi, _ := undirectedIDs(e[i])
-	lidj, hidj, _ := undirectedIDs(e[j])
-
-	if lidi < lidj {
-		return true
-	}
-	sl := lidi == lidj
-	if sl && hidi < hidj {
-		return true
-	}
-	sh := hidi == hidj
-	li, oki := e[i].(graph.Line)
-	lj, okj := e[j].(graph.Line)
-	if oki != okj {
-		panic(fmt.Sprintf("testgraph: mismatched types %T != %T", e[i], e[j]))
-	}
-	if !oki {
-		return sl && sh && lessWeight(e[i], e[j])
-	}
-	if sl && sh && li.ID() < lj.ID() {
-		return true
-	}
-	return sl && sh && li.ID() == lj.ID() && lessWeight(e[i], e[j])
+		if n := cmp.Compare(lida, lidb); n != 0 {
+			return n
+		}
+		if n := cmp.Compare(hida, hidb); n != 0 {
+			return n
+		}
+		la, oka := a.(graph.Line)
+		lb, okb := b.(graph.Line)
+		if oka != okb {
+			panic(fmt.Sprintf("testgraph: mismatched types %T != %T", a, b))
+		}
+		if oka {
+			if n := cmp.Compare(la.ID(), lb.ID()); n != 0 {
+				return n
+			}
+		}
+		return cmpWeight(a, b)
+	})
 }
-func (e lexicalUndirectedEdges) Swap(i, j int) { e[i], e[j] = e[j], e[i] }
 
-func lessWeight(ei, ej Edge) bool {
-	wei, oki := ei.(graph.WeightedEdge)
-	wej, okj := ej.(graph.WeightedEdge)
-	if oki != okj {
-		panic(fmt.Sprintf("testgraph: mismatched types %T != %T", ei, ej))
+func cmpWeight(a, b Edge) int {
+	wea, oka := a.(graph.WeightedEdge)
+	web, okb := b.(graph.WeightedEdge)
+	if oka != okb {
+		panic(fmt.Sprintf("testgraph: mismatched types %T != %T", a, b))
 	}
-	if !oki {
-		return false
+	if !oka {
+		return 0
 	}
-	return wei.Weight() < wej.Weight()
+	return cmp.Compare(wea.Weight(), web.Weight())
 }
 
 // undirectedEdgeSetEqual returned whether a pair of undirected edge
@@ -1409,9 +1400,9 @@ func AddNodes(t *testing.T, g NodeAdder, n int) {
 		}
 	}
 
-	ordered.ByID(addedNodes)
+	order.ByID(addedNodes)
 	graphNodes := graph.NodesOf(g.Nodes())
-	ordered.ByID(graphNodes)
+	order.ByID(graphNodes)
 	if !reflect.DeepEqual(addedNodes, graphNodes) {
 		if n > 20 {
 			t.Errorf("unexpected node set after node addition: got len:%v want len:%v", len(graphNodes), len(addedNodes))
@@ -1486,9 +1477,9 @@ func AddArbitraryNodes(t *testing.T, g NodeAdder, add graph.Nodes) {
 
 	add.Reset()
 	addedNodes := graph.NodesOf(add)
-	ordered.ByID(addedNodes)
+	order.ByID(addedNodes)
 	graphNodes := graph.NodesOf(g.Nodes())
-	ordered.ByID(graphNodes)
+	order.ByID(graphNodes)
 	if !reflect.DeepEqual(addedNodes, graphNodes) {
 		t.Errorf("unexpected node set after node addition: got:\n %v\nwant:\n%v", graphNodes, addedNodes)
 	}
@@ -2102,7 +2093,7 @@ type RandomNodes struct {
 	curr int64
 
 	state *rand.Rand
-	seen  set.Int64s
+	seen  set.Ints[int64]
 	count int
 }
 
@@ -2118,7 +2109,7 @@ func NewRandomNodes(n int, seed uint64, new func(id int64) graph.Node) *RandomNo
 		newNode: new,
 
 		state: rand.New(rand.NewSource(seed)),
-		seen:  make(set.Int64s),
+		seen:  make(set.Ints[int64]),
 		count: 0,
 	}
 }
@@ -2159,7 +2150,7 @@ func (n *RandomNodes) Node() graph.Node {
 // Reset returns the iterator to its initial state.
 func (n *RandomNodes) Reset() {
 	n.state = rand.New(rand.NewSource(n.seed))
-	n.seen = make(set.Int64s)
+	n.seen = make(set.Ints[int64])
 	n.count = 0
 }
 
